import HawAPIOptions from './HawAPIOptions';
import { InMemoryCacheManager } from './cache';
import { EndpointType } from './enums/EndpointType';
import { Filters, Pageable } from './filters';
import { APIInfoModel, ActorSocialModel, BaseModel, BaseTranslation, RequestResult } from './models';
import { Service } from './service';
/**
 * The [HawAPI](https://github.com/HawAPI/HawAPI) js/ts client.
 *
 * - [TypeDoc](https://hawapi.github.io/js-sdk/v1/)
 * - [Github](https://github.com/HawAPI/js-sdk/)
 * - [Examples (Github)](https://github.com/HawAPI/js-sdk/examples/)
 */
export default class HawAPIClient {
    options: HawAPIOptions;
    cache: InMemoryCacheManager;
    headers: HeadersInit;
    request: RequestInit;
    service: Service;
    constructor(options?: Partial<HawAPIOptions>);
    /**
     * Method to test API connection
     * @returns If connected. An {@link string} with 'Ping' value
     */
    ping(): Promise<string>;
    /**
     * Method to get all API informations
     * @returns An new {@link APIInfoModel}
     */
    getInfo(): Promise<APIInfoModel>;
    /**
     * Method to get all client options
     * @returns
     */
    getOptions(): Promise<HawAPIOptions>;
    /**
     * Method to clear all cached data
     * @returns The count of all cleaned data
     */
    clearCache(): Promise<number>;
    /**
     * Method to get all keys of cached data
     * @returns All cached keys
     */
    cacheKeys(): Promise<IterableIterator<string>>;
    /**
     * Method to get the size of cached data
     * @returns The count of all cached data
     */
    cacheSize(): Promise<number>;
    /**
     * Method to remove specific cache data
     * @param key The cache key
     * @returns true if an element in the Map existed and has been removed, or false if the element does not exist.
     */
    removeCache(key: string): Promise<boolean>;
    /**
     * Method that get the API overview
     * @param target The target name
     * @param language The result language
     * @returns An new {@link RequestResult} with overview
     */
    getOverview<OverviewModel>(language: string): Promise<RequestResult<OverviewModel>>;
    /**
     * Method that get all items
     * @param target The target name
     * @param filters
     * @param pageable
     * @returns An new {@link RequestResult} with all target items
     */
    getAll<T extends BaseModel>(target: EndpointType, filters?: Filters | null, pageable?: Pageable | null): Promise<RequestResult<T[]>>;
    /**
     * Method that get a single item
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with specific target item
     */
    getBy<T extends BaseModel>(target: EndpointType, uuid: string): Promise<RequestResult<T>>;
    /**
     * Method that get a single random item
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with random target item
     */
    getRandom<T extends BaseModel>(target: EndpointType): Promise<RequestResult<T>>;
    /**
     * Method that get all item translations
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with all target item translations
     */
    getAllTranslations<T extends BaseTranslation>(target: EndpointType, uuid: string): Promise<RequestResult<T[]>>;
    /**
     * Method that get a single item
     * @param target The target name
     * @param uuid The target uuid
     * @param language The target translation language
     * @returns An new {@link RequestResult} with specific target item translation
     */
    getTranslationBy<T extends BaseTranslation>(target: EndpointType, uuid: string, language: string): Promise<RequestResult<T>>;
    /**
     * Method that get a single random item translation
     * @param target The target name
     * @param uuid The target uuid
     * @returns An new {@link RequestResult} with random target item translation
     */
    getRandomTranslation<T extends BaseModel>(target: EndpointType, uuid: string): Promise<RequestResult<T>>;
    /**
     * Method that get all actor socials
     * @param uuid The actor uuid
     * @returns An new {@link RequestResult} with all actor socials
     */
    getAllSocials(uuid: string): Promise<RequestResult<ActorSocialModel[]>>;
    /**
     * Method that get a single actor social
     * @param uuid The actor uuid
     * @param social The social name
     * @returns An new {@link RequestResult} with an specific actor social
     */
    getSocialBy(uuid: string, social: string): Promise<RequestResult<ActorSocialModel>>;
    /**
     * Method that get a single random actor social
     * @param uuid The actor uuid
     * @returns An new {@link RequestResult} with random social
     */
    getRandomSocial(uuid: string): Promise<RequestResult<ActorSocialModel>>;
}
